==> haskell-extensible-exceptions-0.1.1.4-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-extensible-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 extensible-exceptions
version:              0.1.1.4
visibility:           public
id:                   extensible-exceptions-0.1.1.4-4QtxTJe11myLMCZi4yvSzl
key:                  extensible-exceptions-0.1.1.4-4QtxTJe11myLMCZi4yvSzl
license:              BSD-3-Clause
maintainer:           libraries@haskell.org
synopsis:             Extensible exceptions
description:
    This package provides extensible exceptions for both new and
    old versions of GHC (i.e., < 6.10).

category:             Control
abi:                  66b2d6f781e66454d788713443602ecc
exposed:              True
exposed-modules:      Control.Exception.Extensible
import-dirs:          /usr/lib/ghc-8.8.3/site-local/extensible-exceptions-0.1.1.4
library-dirs:         /usr/lib/ghc-8.8.3/site-local/extensible-exceptions-0.1.1.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.8.3/extensible-exceptions-0.1.1.4

hs-libraries:         HSextensible-exceptions-0.1.1.4-4QtxTJe11myLMCZi4yvSzl
depends:              base-4.13.0.0
haddock-interfaces:
    /usr/share/doc/haskell-extensible-exceptions/html/extensible-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-extensible-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-extensible-exceptions-0.1.1.4-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-extensible-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 extensible-exceptions
version:              0.1.1.4
visibility:           public
id:                   extensible-exceptions-0.1.1.4-JAR9zRD82QsBMqqJXYrd9x
key:                  extensible-exceptions-0.1.1.4-JAR9zRD82QsBMqqJXYrd9x
license:              BSD-3-Clause
maintainer:           libraries@haskell.org
synopsis:             Extensible exceptions
description:
    This package provides extensible exceptions for both new and
    old versions of GHC (i.e., < 6.10).

category:             Control
abi:                  97c95a1e875c7d9292558d875476d704
exposed:              True
exposed-modules:      Control.Exception.Extensible
import-dirs:
    /usr/lib/ghc-8.10.1/site-local/extensible-exceptions-0.1.1.4

library-dirs:
    /usr/lib/ghc-8.10.1/site-local/extensible-exceptions-0.1.1.4

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/extensible-exceptions-0.1.1.4

hs-libraries:         HSextensible-exceptions-0.1.1.4-JAR9zRD82QsBMqqJXYrd9x
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-extensible-exceptions/html/extensible-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-extensible-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
